@@ -30,8 +30,8 @@ class CmdImport(CmdBase):
 
 def add_parser(subparsers, parent_parser):
     IMPORT_HELP = (
-        "Download a file or directory from any DVC project or Git repository "
-        "and take it under DVC control."
+        "Download file or directory from any DVC project or Git repository "
+        "into the workspace, and track it."
     )
 
     import_parser = subparsers.add_parser(
