@@ -125,7 +125,7 @@ class Repo(object):
         self._reset()
 
     def __repr__(self):
-        return "Repo: '{root_dir}'".format(root_dir=self.root_dir)
+        return "{}: '{}'".format(self.__class__.__name__, self.root_dir)
 
     @classmethod
     def find_root(cls, root=None):
@@ -399,14 +399,13 @@ class Repo(object):
 
         abs_path = os.path.abspath(path)
         path_info = PathInfo(abs_path)
-        is_dir = self.tree.isdir(abs_path)
         match = path_info.__eq__ if strict else path_info.isin_or_eq
 
         def func(out):
             if out.scheme == "local" and match(out.path_info):
                 return True
 
-            if is_dir and recursive and out.path_info.isin(path_info):
+            if recursive and out.path_info.isin(path_info):
                 return True
 
             return False
